#!/usr/bin/env python3
#
# Copyright 2024 Spearhead Systems SRL

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersHardware,
)
from cmk.gui.valuespec import Dictionary, Percentage, TextInput, Tuple


def _parameter_valuespec_amd_gpu():
    return Dictionary(
        title=_("GPU utilization"),
        help=_(
            "These metrics are queried directly from the AMD GPU. "
            "Upper and lower levels can be specified for individual metrics."
        ),
        elements=[
            (
                "gpu_percent",
                Tuple(
                    title=_("GPU Used"),
                    help=_("If usage of total GPU compute goes above these percentages, issue alerts."),
                    elements=[
                        Percentage(
                            title=_("Warn if above"),
                            default_value=90
                        ),
                        Percentage(
                            title=_("Crit if above"),
                            default_value=100
                        )
                    ]
                )
            ),
            (
                "vram_free_percent",
                Tuple(
                    title=_("VRAM Free"),
                    help=_("If free VRAM goes above these percentages, issue alerts."),
                    elements=[
                        Percentage(
                            title="Warn if above",
                            default_value=70
                        ),
                        Percentage(
                            title="Crit if above",
                            default_value=90
                        )
                    ]
                )
            ),
            (
                "vram_used_percent",
                Tuple(
                    title=_("VRAM Used"),
                    help=_("If used VRAM goes above these percentages, issue alerts."),
                    elements=[
                        Percentage(
                            title="Warn if above",
                            default_value=70
                        ),
                        Percentage(
                            title="Crit if above",
                            default_value=90
                        )
                    ]
                )
            )
        ]
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="amd_gpu",
        group=RulespecGroupCheckParametersHardware,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_amd_gpu,
        item_spec=lambda: TextInput(title=_("GPU")),
        title=lambda: _("AMD GPU Metrics"),
    )
)
